@@ -15,7 +15,7 @@ BEGIN {
   our $VERSION = '0.001';  # fixed version - NOT handled via DZP::OurPkgVersion.
 }
 
-use Dancer2::Core::Types qw( Bool InstanceOf );
+use Types::Standard qw( Bool InstanceOf );
 use Moo;
 use Sereal::Decoder qw( looks_like_sereal );
 use Sereal::Encoder qw( SRL_UNCOMPRESSED SRL_SNAPPY );
@@ -89,7 +89,7 @@ Dancer2::Plugin::Redis::Serialization::Sereal - Dancer2::Plugin::Redis serializa
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
